@@ -684,7 +684,11 @@ class Installer(object):
         #
         # Change the virtualenv options
         #
-        parser.get_option("--python").help = "Specify the Python interpreter to use, e.g., --python=python2.5 will install with the python2.5 interpreter."
+        parser.remove_option("--python")
+        parser.add_option("--python",
+            dest='python',
+            metavar='PYTHON_EXE',
+            help="Specify the Python interpreter to use, e.g., --python=python2.5 will install with the python2.5 interpreter.")
         parser.remove_option("--relocatable")
         parser.remove_option("--version")
         parser.remove_option("--unzip-setuptools")
@@ -836,7 +840,7 @@ class Installer(object):
         # When preinstalling or working offline, disable the 
         # default install_setuptools() function.
         #
-        if options.preinstall or options.offline:
+        if options.offline:
             install_setuptools.use_default=False
             install_pip.use_default=False
         #
@@ -854,7 +858,8 @@ class Installer(object):
             unzip_file(file, dir=self.abshome_dir)
 
         if options.preinstall or not options.offline:
-            self.get_packages(options)
+            #self.get_packages(options)
+            pass
         else:
             self.sw_packages.insert( 0, Repository('virtualenv', pypi='virtualenv') )
             self.sw_packages.insert( 0, Repository('pip', pypi='pip') )
@@ -971,6 +976,9 @@ class Installer(object):
         else:
             Repository.easy_install_path = [os.path.abspath(join(bindir, 'easy_install.exe'))]
         #
+        if options.preinstall or not options.offline:
+            self.get_packages(options)
+        #
         # Install the related packages
         #
         for pkg in self.sw_packages:
